aboutsummaryrefslogtreecommitdiffstats
path: root/tools/search_brave.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/search_brave.sh')
-rwxr-xr-xtools/search_brave.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/search_brave.sh b/tools/search_brave.sh
index 9886944..f76e9ca 100755
--- a/tools/search_brave.sh
+++ b/tools/search_brave.sh
@@ -5,16 +5,16 @@ set -e
# Use this when you need current information or feel a search could provide a better answer.
# @env BRAVE_API_KEY! The api key
# @env BRAVE_MAX_RESULTS=5 The max results to return.
# @option --query! The query to search for.
main() {
encoded_query="$(jq -nr --arg q "$argc_query" '$q|@uri')"
- url="https://api.search.brave.com/res/v1/web/search?q=$encoded_query&count=$BRAVE_MAX_RESULTS"
+ url="https://api.search.brave.com/res/v1/web/search?q=$encoded_query&count=$SEARCH_MAX_RESULTS"
curl -fsSL "$url" \
-H "Accept: application/json" \
-H "X-Subscription-Token: $BRAVE_API_KEY" | \
- jq '[.web.results[] | {title: .title, url: .url, description: .description}]' \
+ jq '[.web.results[] | {link: .url, title: .title, snippet: .description}]' \
>> "$LLM_OUTPUT"
}
@@ -5,16 +5,16 @@ set -e
# Use this when you need current information or feel a search could provide a better answer.
# @env BRAVE_API_KEY! The api key
-# @env BRAVE_MAX_RESULTS=5 The max results to return.
+# @env SEARCH_MAX_RESULTS=5 The max results to return.
# @option --query! The query to search for.
main() {